@@ -1,8 +1,24 @@
-from acme.app import run, demo
+from acme.data.constants import SUCCESS, FAIL
+from acme.files import get_employees_from_file, write_employees_data
 
-SUCCESS = 1
-FAIL = 0
-ERROR = -1
+
+def processing(argv):
+    """Processing the command and check argument"""
+
+    options = ['-d', '--demo', '-h', '--help']
+    is_option = argv[0] in options or argv[0].endswith('.txt')
+
+    completed = FAIL
+
+    if is_option:
+        completed = check(argv)
+
+    err = {
+        FAIL:  'Invalid argument.\nFor more information run: acme --help'
+    }
+
+    if completed != SUCCESS:
+        print(err.get(completed))
 
 
 def check(argv):
@@ -22,24 +38,25 @@ def check(argv):
     return completed
 
 
-def processing(argv):
-    """Processing the command and check argument"""
+def run(file):
+    completed = 0
+    employees = get_employees_from_file(file)
+    if employees:
+        for employee in employees:
+            print('The amount to pay {} is: {:.2f} USD'.format(
+                employee.name, employee.salary)
+            )
+        completed = 1
 
-    options = ['-d', '--demo', '-h', '--help']
-    is_option = argv[0] in options or argv[0].endswith('.txt')
+    return completed
 
-    completed = FAIL
 
-    if is_option:
-        completed = check(argv)
+def demo():
+    completed = 0
+    write_employees_data()
+    completed = run('employees.txt')
 
-    err = {
-        FAIL:  'Invalid argument.\nFor more information run: acme --help',
-        ERROR: 'An error ocurred',
-    }
-
-    if completed != SUCCESS:
-        print(err.get(completed))
+    return completed
 
 
 def instructions():
@@ -59,13 +76,15 @@ def instructions():
     Usage:
         acme <file>
         
-        Ensure the file is a text (.txt) file"""
+        Ensure the file is a text (.txt) file.
+        In addition, that the file is in the same
+        directory where the command is executed."""
 
     options = """
     Options:
-        -d  : Create a demo file with default name (data.txt) 
-              and execute the app (also --demo)
-        -h  : Print the instructions (also --help)"""
+        -d, --demo  : Create a demo file (employees.txt) 
+                      and execute acme employees.txt.
+        -h, --help  : Print the instructions."""
 
     examples = """
     Examples:
